package com.flossom.system.service;

import com.flossom.common.core.domain.entity.WxInstrumentInstructions;

import java.util.List;

/**
 * 仪器说明书Service接口
 *
 * @author flossom
 * @date 2024-01-16
 */
public interface IWxInstrumentInstructionsService {
    /**
     * 查询仪器说明书
     *
     * @param id 仪器说明书主键
     * @return 仪器说明书
     */
    public WxInstrumentInstructions selectWxInstrumentInstructionsById(Long id);

    /**
     * 查询仪器说明书列表
     *
     * @param wxInstrumentInstructions 仪器说明书
     * @return 仪器说明书集合
     */
    public List<WxInstrumentInstructions> selectWxInstrumentInstructionsList(WxInstrumentInstructions wxInstrumentInstructions);

    /**
     * 新增仪器说明书
     *
     * @param wxInstrumentInstructions 仪器说明书
     * @return 结果
     */
    public int insertWxInstrumentInstructions(WxInstrumentInstructions wxInstrumentInstructions);

    /**
     * 修改仪器说明书
     *
     * @param wxInstrumentInstructions 仪器说明书
     * @return 结果
     */
    public int updateWxInstrumentInstructions(WxInstrumentInstructions wxInstrumentInstructions);

    /**
     * 批量删除仪器说明书
     *
     * @param ids 需要删除的仪器说明书主键集合
     * @return 结果
     */
    public int deleteWxInstrumentInstructionsByIds(Long[] ids);

    /**
     * 删除仪器说明书信息
     *
     * @param id 仪器说明书主键
     * @return 结果
     */
    public int deleteWxInstrumentInstructionsById(Long id);
}
